@@ -292,9 +292,11 @@ class FixtureRegistry:
 
     def get_scheduled_fixtures_for_scope(self, direct_fixtures, scope, parent_scheduled_fixtures=None):
         fixtures = OrderedSet()
+
         for fixture in direct_fixtures:
             fixtures.update(self.get_fixture_dependencies(fixture))
-        fixtures.update(direct_fixtures)
+            fixtures.add(fixture)
+
         return ScheduledFixtures(
             scope, [self._fixtures[name] for name in fixtures if self._fixtures[name].scope == scope],
             parent_scheduled_fixtures=parent_scheduled_fixtures
@@ -373,12 +375,12 @@ def load_fixtures_from_files(patterns, excluding=[]):
 
     :param patterns: a mandatory list (a simple string can also be used instead of a single element list)
         of files to import; the wildcard '*' character can be used
-    :param exclude: an optional list (a simple string can also be used instead of a single element list)
+    :param excluding: an optional list (a simple string can also be used instead of a single element list)
       of elements to exclude from the expanded list of files to import
 
     Example::
 
-        load_suites_from_files("test_*.py")
+        load_fixtures_from_files("test_*.py")
     """
     fixtures = []
     for file in get_matching_files(patterns, excluding):
